<?php
namespace LandkitElementor\Includes\Controls;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

use Elementor\Base_Data_Control;

/**
 * Elementor animation control.
 *
 * A base control for creating entrance animation control. Displays a select box
 * with the available entrance animation effects @see Control_Aos_Animation::get_animations() .
 *
 * @since 1.0.0
 */
class Control_Aos_Animation extends Base_Data_Control {

    /**
     * Get control type.
     *
     * Retrieve the animation control type.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Control type.
     */
    public function get_type() {
        return 'aos_animation';
    }

    /**
     * Retrieve default control settings.
     *
     * Get the default settings of the control. Used to return the default
     * settings while initializing the control.
     *
     * @since 2.5.0
     * @access protected
     *
     * @return array Control default settings.
     */
    protected function get_default_settings() {
        return [
            'label_block' => true,
        ];
    }

    /**
     * Get animations list.
     *
     * Retrieve the list of all the available animations.
     *
     * @since 1.0.0
     * @access public
     * @static
     *
     * @return array Control type.
     */
    public static function get_animations() {
        $animations = [
            'Fade' => [
                'fade' => 'Fade',
                'fade-up' => 'Fade Up',
                'fade-down' => 'Fade Down',
                'fade-left' => 'Fade Left',
                'fade-right' => 'Fade Right',
                'fade-up-right' => 'Fade Up Right',
                'fade-up-left' => 'Fade up Left',
                'fade-down-right' => 'Fade Down Right',
                'fade-down-left' => 'Fade down Left',
            ],
            'Flip' => [
                'flip-up' => 'Flip Up',
                'flip-down' => 'Flip Down',
                'flip-left' => 'Flip Left',
                'flip-right' => 'Flip Right',
            ],
            'Slide' => [
                'slide-up' => 'Slide Up',
                'slide-down' => 'Slide Down',
                'slide-left' => 'Slide Left',
                'slide-right' => 'Slide Right',
            ],
            'Zoom' => [
                'zoom-in' => 'Zoom In',
                'zoom-in-up' => 'Zoom In Up',
                'zoom-in-down' => 'Zoom In Down',
                'zoom-in-left' => 'Zoom In Left',
                'zoom-in-right' => 'Zoom In Right',
                'zoom-out' => 'Zoom Out',
                'zoom-out-up' => 'Zoom Out Up',
                'zoom-out-down' => 'Zoom Out Down',
                'zoom-out-left' => 'Zoom Out Left',
                'zoom-out-right' => 'Zoom Out Right',
            ],
        ];

        /**
         * Element appearance animations list.
         *
         * @since 2.4.0
         *
         * @param array $additional_animations Additional Animations array.
         */
        $additional_animations = apply_filters( 'landkit_elementor/controls/aos-animations/additional_animations', [] );

        return array_merge( $animations, $additional_animations );
    }

    /**
     * Render animations control template.
     *
     * Used to generate the control HTML in the editor using Underscore JS
     * template. The variables for the class are available using `data` JS
     * object.
     *
     * @since 1.0.0
     * @access public
     */
    public function content_template() {
        $control_uid = $this->get_control_uid();
        ?>
        <div class="elementor-control-field">
            <label for="<?php echo $control_uid; ?>" class="elementor-control-title">{{{ data.label }}}</label>
            <div class="elementor-control-input-wrapper">
                <select id="<?php echo $control_uid; ?>" data-setting="{{ data.name }}">
                    <option value=""><?php echo __( 'Default', 'landkit-elementor' ); ?></option>
                    <option value="none"><?php echo __( 'None', 'landkit-elementor' ); ?></option>
                    <?php foreach ( static::get_animations() as $animations_group_name => $animations_group ) : ?>
                        <optgroup label="<?php echo $animations_group_name; ?>">
                            <?php foreach ( $animations_group as $animation_name => $animation_title ) : ?>
                                <option value="<?php echo $animation_name; ?>"><?php echo $animation_title; ?></option>
                            <?php endforeach; ?>
                        </optgroup>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>
        <# if ( data.description ) { #>
        <div class="elementor-control-field-description">{{{ data.description }}}</div>
        <# } #>
        <?php
    }
}
