<?php
namespace LandkitElementor\Modules\badge\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

use Elementor\Core\Schemes;
use Elementor;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Icons_Manager;

/**
 * Landkit Elementor badge widget.
 *
 * Landkit Elementor widget that displays a badge with the ability to control every
 * aspect of the badge design.
 *
 * @since 1.0.0
 */
class Badge extends Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve badge widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'lk-badge';
    }

    /**
     * Get widget title.
     *
     * Retrieve badge widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Badge', 'landkit-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve badge widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-banner';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the badge widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * @since 2.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return [ 'landkit' ];
    }

    /**
     * Register badge widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function register_controls() {

        // Content Tab Start
        $this->start_controls_section(
            'section_header',
            [
                'label' => esc_html__( 'Badge', 'landkit-elementor' ),
            ]
        );

        $this->add_control(
            'badge_text',
            [
                'label'     => esc_html__( 'Badge Text', 'landkit-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => esc_html__( 'Badge', 'landkit-elementor' ),
                'condition' => [ 'badge_shape!' => ' badge-rounded-circle' ],
            ]
        );

        $this->add_control(
            'badge_size',
            [
                'label'   => esc_html__( 'Badge Size', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'default' => 'Default',
                    'lg'      => 'Large',
                ],
                'default' => 'default',
            ]
        );

        $this->add_control(
            'badge_shape',
            [
                'label'   => esc_html__( 'Badge Shape', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    ''                      => esc_html__( 'Default', 'landkit-elementor' ),
                    ' badge-pill'           => esc_html__( 'Pill', 'landkit-elementor' ),
                    ' badge-rounded-circle' => esc_html__( 'Rounded', 'landkit-elementor' ),
                ],
                'default' => '',
            ]
        );

        $this->add_control(
            'badge_float',
            [
                'label'   => esc_html__( 'Badge float ?', 'landkit-elementor' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'no',
                'frontend_available' => true,
            ]
        );

        $this->add_control(
            'badge_float_side',
            [
                'label'     => esc_html__( 'Float Side', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'condition' => [ 'badge_float' => 'yes' ],
                'options'   => [
                    'badge-float-inside'  => esc_html__( 'Float Inside', 'landkit-elementor' ),
                    'badge-float-outside' => esc_html__( 'Float Outside', 'landkit-elementor' )
                ],
                'default'   => 'badge-float-inside',
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label'        => esc_html__( 'Alignment', 'landkit-elementor' ),
                'type'         => Controls_Manager::CHOOSE,
                'options'      => [
                    'left'   => [
                        'title' => esc_html__( 'Left', 'landkit-elementor' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'landkit-elementor' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'landkit-elementor' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'default'      => '',
                'condition'    => [ 'badge_float!' => 'yes' ],
            ]
        );

        $this->add_control(
            'selected_icon',
            [
                'label'            => esc_html__( 'Icon', 'landkit-elementor' ),
                'type'             => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'condition'        => [ 'badge_shape' => ' badge-rounded-circle' ],
            ]
        );

        // Content Tab End
        $this->end_controls_section();

        $this->start_controls_section(
            'additional_class',
            [
                'label' => esc_html__( 'Additional Settings', 'landkit-elementor' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'badge_predefined_color',
            [
                'label'   => esc_html__( 'Badge Background', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'primary'       => esc_html__( 'Primary', 'landkit-elementor' ),
                    'primary-desat' => esc_html__( 'Primary Desat', 'landkit-elementor' ),
                    'secondary'     => esc_html__( 'Secondary', 'landkit-elementor' ),
                    'success'       => esc_html__( 'Success', 'landkit-elementor' ),
                    'danger'        => esc_html__( 'Danger', 'landkit-elementor' ),
                    'warning'       => esc_html__( 'Warning', 'landkit-elementor' ),
                    'info'          => esc_html__( 'Info', 'landkit-elementor' ),
                    'light'         => esc_html__( 'Light', 'landkit-elementor' ),
                    'dark'          => esc_html__( 'Dark', 'landkit-elementor' ),
                    'custom'        => esc_html__( 'Custom', 'landkit-elementor' ),
                ],
                'default' => 'primary',
            ]
        );

        $this->add_control(
            'badge_soft',
            [
                'label'     => esc_html__( 'Badge Soft ?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'frontend_available' => true,
                'condition' => [ 'badge_predefined_color!' => 'custom' ]
            ]
        );

        $this->add_control(
            'color',
            [
                'label'     => esc_html__( 'Text Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .badge' => 'color: {{VALUE}};',
                ],
                'condition' => [ 'badge_predefined_color' => 'custom' ]
            ]
        );

        $this->add_control(
            'background_color',
            [
                'label'     => esc_html__( 'Background Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .badge' => 'background-color: {{VALUE}};',
                ],
                'condition' => [ 'badge_predefined_color' => 'custom' ]
            ]
        );

        $this->add_control(
            'wrapper_css_class',
            [
                'label'   => esc_html__( 'Wrapper CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for wrapper without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => 'mb-3'
            ]
        );

        $this->add_control(
            'text_css_class',
            [
                'label'   => esc_html__( 'Text CSS Class', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'title'   => esc_html__( 'Add your custom class for text without the dot. e.g: my-class', 'landkit-elementor' ),
                'default' => 'text-uppercase h6'
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render badge widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();

        if ( empty( $settings['icon'] ) && ! Icons_Manager::is_migration_allowed() ) {
            $settings['icon'] = 'fa fa-star';
        }

        if ( ! empty( $settings[ 'text_css_class' ] ) ) {
            $this->add_render_attribute( 'text', 'class', $settings[ 'text_css_class' ] );
        }

        $this->add_render_attribute( 'badge', 'class', [
            'badge',
            'badge-' . $settings['badge_predefined_color'] . ( $settings['badge_soft'] === 'yes' ? '-soft': '' ),
            $settings[ 'wrapper_css_class' ]
        ] );

        if ( ! empty( $settings['badge_size'] ) && 'lg' == $settings['badge_size'] ) {
            $this->add_render_attribute( 'badge', 'class', 'badge-lg' );
        }

        if ( ! empty( $settings[' badge_float'] ) && 'yes' === $settings['badge_float'] ) {
            $this->add_render_attribute( 'badge', 'class', 'badge-float ' . $settings['badge_float_side'] );
        }

        if ( ! empty( $settings['badge_shape'] ) ) {
            $this->add_render_attribute( 'badge', 'class', $settings['badge_shape'] );   
        }

        $migrated = isset( $settings['__fa4_migrated']['selected_icon'] );
        $is_new   = empty( $settings['icon'] ) && Icons_Manager::is_migration_allowed();

        ?>
        <span <?php echo $this->get_render_attribute_string( 'badge' ); ?>>
            <?php if ( $settings[ 'badge_shape' ] != ' badge-rounded-circle' ) :
                ?> <span <?php echo $this->get_render_attribute_string( 'text' ); ?>><?php echo $settings[ 'badge_text' ] ?></span> <?php 
            else : ?>
                <?php if ( $is_new || $migrated ) :
                    Icons_Manager::render_icon( $settings['selected_icon'], [ 'aria-hidden' => 'true' ] );
                else : ?>
                    <i <?php echo $this->get_render_attribute_string( 'icon' ); ?>></i>
                <?php endif; ?>
            <?php endif; ?>
        </span>
        <?php
    }

    /**
     * Render badge widget output in the editor.
     *
     * Written as a Backbone JavaScript template and used to generate the live preview.
     *
     * @since 2.9.0
     * @access protected
     */
    protected function content_template() {
        ?>
        <# var iconHTML = elementor.helpers.renderIcon( view, settings.selected_icon, { 'aria-hidden': true }, 'i' , 'object' ),
            migrated = elementor.helpers.isIconMigrated( settings, 'selected_icon' );


            view.addRenderAttribute( 'badge', 'class', [ 
                'badge',
                settings.wrapper_css_class,
            ] );

            if ( '' !== settings.badge_soft ) {
                view.addRenderAttribute( 'badge', 'class', [
                    'badge-' + settings.badge_predefined_color + '-soft', 
                ] );
            } else {
                view.addRenderAttribute( 'badge', 'class', [
                    'badge-' + settings.badge_predefined_color, 
                ] );
            }

            if ( '' !== settings.badge_size && 'lg' === settings.badge_size ) {
                view.addRenderAttribute( 'badge', 'class', 'badge-lg' );
            }

            if ( '' !== settings.badge_float && 'yes' === settings.badge_float ) {
                view.addRenderAttribute( 'badge', 'class',  'badge-float ' + settings.badge_float_side );
            }

            if ( '' !== settings.badge_shape ) {
                view.addRenderAttribute( 'badge', 'class', settings.badge_shape );   
            }

        #>
        <span {{{ view.getRenderAttributeString( 'badge' ) }}}>
            <# if ( settings.badge_shape  != ' badge-rounded-circle' ) { #>
                <span class="{{ settings.text_css_class }}">{{{ settings.badge_text }}}</span>
            <# } else { #>
                <# if ( ( migrated || ! settings.icon ) && iconHTML.rendered ) { #>
                    {{{ iconHTML.value }}}
                <# } else { #>
                    <i class="{{ settings.icon }}" aria-hidden="true"></i>
                <# } #>
            <# } #>
        </span>
        <?php

    }
}