<?php
namespace LandkitElementor\Modules\Carousel\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Plugin;

/**
 * Landkit Elementor brands carousel widget.
 *
 * Landkit Elementor widget that displays a brands carousel with the ability to control every
 * aspect of the brands carousel design.
 *
 * @since 1.0.0
 */
class Brands_Carousel extends Base {

    private $files_upload_handler = false;

    /**
     * Get widget name.
     *
     * Retrieve brands carousel widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'lk-brands-carousel';
    }

    /**
     * Get widget title.
     *
     * Retrieve brands carousel widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Brands Carousel', 'landkit-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve brands carousel widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-carousel';
    }

    /**
     * Get widget keywords.
     *
     * Retrieve the list of keywords the widget belongs to.
     *
     * @since 2.1.0
     * @access public
     *
     * @return array Widget keywords.
     */
    public function get_keywords() {
        return [ 'brands', 'brands-carousel', 'carousel', 'image' ];
    }

    /**
     * Register brands carousel widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function register_controls() {
        parent::register_controls();

        $this->remove_control( 'show_arrows' );
        $this->remove_control( 'loop' );
        $this->remove_control( 'image_class' );
        $this->update_responsive_control(
            'slides_per_view', [
                'options'   => [
                    ''      => __( 'Default', 'landkit-elementor' ),
                    '1'     => __( '1', 'landkit-elementor' ),
                    '2'     => __( '2', 'landkit-elementor' ),
                    '3'     => __( '3', 'landkit-elementor' ),
                    '4'     => __( '4', 'landkit-elementor' ),
                    '6'     => __( '6', 'landkit-elementor' ),
                    '12'    => __( '12', 'landkit-elementor' ),
                ],
            ]
        );

        $this->start_injection( [
            'of' => 'pause_on_hover',
        ] );

        $this->add_control(
            'enable_viewport_width', [
                'label'         => esc_html__( 'Enable Viewport Width', 'landkit-elementor' ),
                'type'          => Controls_Manager::SWITCHER,
                'label_on'      => esc_html__( 'Yes', 'landkit-elementor' ),
                'label_off'     => esc_html__( 'No', 'landkit-elementor' ), 
                'return_value'  => 'yes',
                'default'       => 'yes',
                'separator'     => 'before',
            ]
        );

        $this->end_injection();
    }

    protected function add_repeater_controls( Repeater $repeater ) {
        $enabled = Plugin::$instance->uploads_manager->are_unfiltered_uploads_enabled();

        $repeater->add_control(
            'logo', [
                'label' => __( 'Logo', 'landkit-elementor' ),
                'type'  => Controls_Manager::MEDIA,
            ]
        );

        if ( $enabled ) {
            $repeater->add_control(
                'logo_inline_svg', [
                   'label'          => esc_html__( 'Inline SVG', 'landkit-elementor' ),
                    'type'          => Controls_Manager::SWITCHER,
                    'title'         => esc_html__( 'If you are uploading SVG file, it might be useful to inline the SVG files. Do not inline, if your SVG file is from unknown sources.', 'landkit-elementor' ),
                    'label_on'      => esc_html__( 'Yes', 'landkit-elementor' ),
                    'label_off'     => esc_html__( 'No', 'landkit-elementor' ), 
                    'return_value'  => 'yes',
                    'default'       => 'no',
                ]
            );

            $repeater->add_control(
                'logo_svg_color', [
                    'label'         => esc_html__( 'SVG Color', 'landkit-elementor' ),
                    'type'          => Controls_Manager::COLOR,
                    'selectors'     => [ '{{WRAPPER}} {{CURRENT_ITEM}} .brand-svg path' => 'fill: {{VALUE}};', ],
                    'condition'     => [ 'logo_inline_svg' => 'yes', ],
                ]
            );
        }
    }

    protected function get_repeater_defaults() {
        $placeholder_image_src = Utils::get_placeholder_image_src();

        $defaults = [];

        for ($i=0; $i < 12; $i++) { 
            $defaults[] = [
                'logo'  => [
                    'url'   => $placeholder_image_src,
                ],
            ];
        }

        return $defaults;
    }

    protected function print_slide( array $slide, array $settings, $element_key ) {
        if( empty( $slide['logo']['url'] ) ) {
            return;
        }

        $column = ! empty( $settings['slides_per_view_mobile'] ) ? 12/intval( $settings['slides_per_view_mobile'] ) : 4;
        $column_md = ! empty( $settings['slides_per_view_tablet'] ) ? 12/intval( $settings['slides_per_view_tablet'] ) : 3;
        $column_lg = ! empty( $settings['slides_per_view'] ) ? 12/intval( $settings['slides_per_view'] ) : 2;

        $this->add_render_attribute( $element_key . '-column-wrapper', 'class', [
            'col-' . $column,
            'col-md-' . $column_md,
            'col-lg-' . $column_lg,
            'elementor-repeater-item-' . $slide['_id'],
        ] );

        $file_ext = pathinfo( $slide['logo']['url'], PATHINFO_EXTENSION );
        $file_ext = pathinfo( $slide['logo']['url'], PATHINFO_EXTENSION );
        $is_svg_logo = $file_ext === 'svg' ? true : false;
        $load_svg_logo = $this->files_upload_handler && isset( $slide['logo_inline_svg'] ) && $slide['logo_inline_svg'] === 'yes' && $is_svg_logo;

        ?>
        <div <?php echo $this->get_render_attribute_string( $element_key . '-column-wrapper' ); ?>>
            <div class="img-fluid text-white brand-svg<?php if ( $is_svg_logo ) echo esc_attr( ' svg-shim' ); ?>">
                <?php if( $load_svg_logo ) :
                    $content = wp_remote_get( $slide['logo']['url'] );
                    print_r( $content['body'] );
                else :
                    $this->add_render_attribute( $element_key . '-image', [
                        'src' => $slide['logo']['url'],
                        'alt' => ! empty( $slide['name'] ) ? $slide['name'] : '',
                    ] );
                    ?><img <?php echo $this->get_render_attribute_string( $element_key . '-image' ); ?>><?php
                endif; ?>
            </div>
        </div>
        <?php
    }

    protected function render() {
        $uniqId = 'barands-slider-' . $this->get_id();
        $settings = $this->get_settings_for_display();
        $this->files_upload_handler = Plugin::$instance->uploads_manager->are_unfiltered_uploads_enabled();

        $default_settings = [];

        $settings = array_merge( $default_settings, $settings );

        $slides_count = isset( $settings['slides'] ) ? count( $settings['slides'] ) : 1;

        $default_carousel_settings = apply_filters( 'landkit_brands_carousel_default_carousel_args', [
            'contain'           => true,
            'pageDots'          => false,
            'imagesLoaded'      => true,
            'initialIndex'      => $slides_count > 6 ? 6 : $slides_count,
            'wrapAround'        => false,
            'prevNextButtons'   => false,
        ] );

        $carousel_settings = apply_filters( 'landkit_brands_carousel_default_carousel_args', [
            'pageDots'          => isset( $settings['pagination'] ) && $settings['pagination'] === 'yes' ? true : false,
            'prevNextButtons'   => isset( $settings['show_arrows'] ) && $settings['show_arrows'] === 'yes' ? true : false,
        ] );

        $carousel_settings = array_merge( $default_carousel_settings, $carousel_settings );

        if( isset( $settings['autoplay'] ) && $settings['autoplay'] === 'yes' ) {
            $carousel_settings['autoPlay']              = $settings['autoplay_speed'] ? intval( $settings['autoplay_speed'] ) : 1500;
            $carousel_settings['pauseAutoPlayOnHover']  = isset( $settings['pause_on_hover'] ) && $settings['pause_on_hover'] === 'yes' ? true : false;
        }

        $this->add_render_attribute(
            'brands-slider', [
                'class'         => 'brands-slider',
                'data-flickity' => htmlspecialchars( json_encode( $carousel_settings ), ENT_QUOTES, 'UTF-8' ),
                'data-aos-id'   => 'flickity:in',
                'data-aos'      => '1',
            ]
        );

        if( isset( $settings['enable_viewport_width'] ) && $settings['enable_viewport_width'] === 'yes' ) {
            $this->add_render_attribute( 'brands-slider', 'class', 'flickity-viewport-visible' );
        }

        ?>
        <div <?php echo $this->get_render_attribute_string( 'brands-slider' ); ?>>
            <?php
            foreach ( $settings['slides'] as $slide ) :
                $this->print_slide( $slide, $settings, 'brand-slide-' . $slide['_id'] );
            endforeach;
            ?>
        </div>
        <?php
    }
}
