<?php
namespace LandkitElementor\Modules\Carousel\Widgets;

use Elementor;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Plugin;


if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Image_Box_Carousel extends Base {

    private $slide_prints_count = 0;

    public function get_name() {
        return 'lk-image-box-carousel';
    }

    public function get_title() {
        return __( 'Image Box Carousel', 'landkit-elementor' );
    }

    public function get_icon() {
        return 'eicon-image-box';
    }

    public function get_keywords() {
        return [ 'image-box-carousel', 'image-box', 'carousel', 'image' ];
    }

    /**
     * Register image-box carousel widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function register_controls() {
        parent::register_controls();

        $this->remove_control( 'show_arrows' );
        $this->remove_control( 'pagination' );
        $this->remove_control( 'loop' );

        $this->update_control(
            'autoplay_speed', [
                'default' => 'no',
            ]
        );

        $enabled = Plugin::$instance->uploads_manager->are_unfiltered_uploads_enabled();

        if ( $enabled ) {
            $this->start_injection( [
                'of' => 'slides_per_view',
            ] );

            $this->add_control(
                'inline_svg',
                [
                   'label'         => esc_html__( 'Inline SVG', 'landkit-elementor' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'title'        => esc_html__( 'If you are uploading SVG file, it might be useful to inline the SVG files. Do not inline, if your SVG file is from unknown sources.', 'landkit-elementor' ),
                    'label_on'     => esc_html__( 'Yes', 'landkit-elementor' ),
                    'label_off'    => esc_html__( 'No', 'landkit-elementor' ), 
                    'return_value' => 'yes',
                    'default'      => 'no',
                ]
            );
        }

        $this->start_controls_section(
            'section_style_text',
            [
                'label' => esc_html__( 'Slides', 'landkit-elementor' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'content_typo_style', [
                'type'  => Controls_Manager::HEADING,
                'label' => esc_html__( 'Content Text Styles', 'landkit-elementor' ),
            ]
        );

        $this->add_control(
            'content_color', [
                'label'     => esc_html__( 'Content Text Color', 'landkit-elementor' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .lk-image-box__content' => 'color: {{VALUE}}',

                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'content_typography',
                'selector' => '{{WRAPPER}} .lk-image-box__content',
            ]
        );

        $this->add_control(
            'read_more_typo_style', [
                'type'      => Controls_Manager::HEADING,
                'label'     => esc_html__( 'Action Link Styles', 'landkit-elementor' ),
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'read_more_typography',
                'selector' => '{{WRAPPER}} .lk-image-box__readmore',
            ]
        );

        $this->end_controls_section();
    }

    protected function add_repeater_controls( Repeater $repeater ) {

        $repeater->add_control(
            'logo', [
                'label' => esc_html__( 'Logo', 'landkit-elementor' ),
                'type'  => Controls_Manager::MEDIA,
            ]
        );

        $repeater->add_control(
            'content', [
                'label' => esc_html__( 'Content', 'landkit-elementor' ),
                'type'  => Controls_Manager::TEXTAREA,
            ]
        );

        $repeater->add_control(
            'readmore', [
                'label' => esc_html__( 'Action Link Text', 'landkit-elementor' ),
                'type'  => Controls_Manager::TEXT,
            ]
        );

        $repeater->add_control(
            'link', [
                'label'       => esc_html__( 'Action Link', 'landkit-elementor' ),
                'type'        => Elementor\Controls_Manager::URL,
                'dynamic'     => [
                    'active' => true,
                ],
                'placeholder' => esc_html__( 'https://your-link.com', 'landkit-elementor' ),
                'default'     => [
                    'url' => '#',
                ],
            ]
        );

        $repeater->add_control(
            'color', [
                'label'       => esc_html__( 'Color', 'landkit-elementor' ),
                'type'        => Controls_Manager::COLOR,
                'global'      => 'no',
                'description' => esc_html__( 'Applied to border-top, image if inline SVG enabled and read more link', 'landkit-elementor' ),
                'selectors'   => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .lk-image-box'           => 'border-top-color: {{VALUE}}',
                    '{{WRAPPER}} {{CURRENT_ITEM}} .lk-image-box__readmore' => 'color: {{VALUE}}',
                    '{{WRAPPER}} {{CURRENT_ITEM}} .lk-image-box__svg'      => 'color: {{VALUE}}',
                ],
            ]
        );
    }

    protected function get_repeater_defaults() {
        $placeholder_image_src = Utils::get_placeholder_image_src();

        $colors = [
            '#FF5A5F', '#B81D24', '#0081C9', '#6772E5', '#CB2027', '#DA5988'
        ];

        $defaults = [];

        foreach ( $colors as $color ) {
            $defaults[] = [
                'content'  => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.', 'landkit-elementor' ),
                'readmore' => esc_html__( 'Read More', 'landkit-elementor' ),
                'logo'     => [ 'url' => $placeholder_image_src ],
                'color'    => $color
            ];
        }

        return $defaults;
    }

    protected function print_slide( array $slide, array $settings, $element_key ) {
        if ( ! empty( $slide['logo']['url'] ) ) {
            $this->add_render_attribute( $element_key . '-logo', [
                'src'   => $slide['logo']['url'],
                'alt'   => 'image',
                'class' => 'img-fluid mb-5 w-50 mx-auto',
            ] );
        }
        if ( ! empty( $slide['border_color'] ) ) {
            $this->add_render_attribute( $element_key . '-color', [
                'src'   => $slide['logo']['url'],
                'alt'   => 'image',
                'class' => 'img-fluid mb-5 w-50 mx-auto',
            ] );
        }

        $enabled = Plugin::$instance->uploads_manager->are_unfiltered_uploads_enabled();

        $column    = ! empty( $settings['slides_per_view_mobile'] ) ? 12/intval( $settings['slides_per_view_mobile'] ) : 12;
        $column_md = ! empty( $settings['slides_per_view_tablet'] ) ? 12/intval( $settings['slides_per_view_tablet'] ) : 5;
        $column_lg = ! empty( $settings['slides_per_view'] ) ? 12/intval( $settings['slides_per_view'] ) : 4;

        $this->add_render_attribute( $element_key . '-column-wrapper', 'class', [
            'elementor-repeater-item-' . $slide['_id'], 'col-' . $column, 'col-md-' . $column_md, 'col-lg-' . $column_lg
        ] );

        $link_key = 'link_' . $element_key;
        $logo     = 'logo_' . $element_key;

        $this->add_link_attributes( $link_key, $slide['link'] );

        $file_ext = pathinfo( $slide['logo']['url'], PATHINFO_EXTENSION );

        ?><div <?php echo $this->get_render_attribute_string( $element_key . '-column-wrapper' ); ?>>
            <div class="lk-image-box card card-border shadow-light-lg lift lift-lg">
                <div class="card-body text-center">
                    <div class="img-fluid mb-5 w-50 mx-auto <?php if ( $file_ext === 'svg' ) echo esc_attr( ' lk-image-box__svg svg-shim' ); ?>">
                        <?php if( $enabled && isset( $settings['inline_svg'] ) && $settings['inline_svg'] === 'yes' && $file_ext === 'svg' ) :
                            $content = file_get_contents( $slide['logo']['url'] );
                            print( $content );
                        else :
                            $this->add_render_attribute( $element_key . '-image', [
                                'src' => $slide['logo']['url'],
                                'alt' => ! empty( $slide['name'] ) ? $slide['name'] : '',
                                'class' => $settings['image_class']
                            ] );
                            ?><img <?php echo $this->get_render_attribute_string( $element_key . '-image' ); ?>><?php
                        endif; ?>
                    </div>
                    <p class="lk-image-box__content mb-5">
                        <?php echo $slide['content']; ?>
                    </p>
                    <?php if ( ! empty( $slide['readmore'] ) ) : ?>
                        <a class="lk-image-box__readmore" <?php echo $this->get_render_attribute_string( $link_key ); ?>><?php echo $slide['readmore']; ?></a>
                    <?php endif; ?>
                </div>
            </div>
        </div><?php
    }

    protected function render() {
        $uniqId   = 'image-box-slider-' . $this->get_id();
        $settings = $this->get_settings_for_display();
        $slides   = isset( $settings['slides'] ) ? count( $settings['slides'] ) : 1;
        $defaults = apply_filters( 'landkit-elementor/widget/image-box-carousel/default-args', [
            'cellAlign'       => 'left',
            'contain'         => true,
            'pageDots'        => false,
            'imagesLoaded'    => true,
            'prevNextButtons' => false,
            
        ] );
        $args = apply_filters( 'landkit-elementor/widget/image-box-carousel/args', [
            'pageDots'        => isset( $settings['pagination'] ) && $settings['pagination'] === 'yes' ? true : false,
            'prevNextButtons' => isset( $settings['show_arrows'] ) && $settings['show_arrows'] === 'yes' ? true : false,
        ] );

        $args = array_merge( $defaults, $args );

        if( isset( $settings['autoplay'] ) && $settings['autoplay'] === 'yes' ) {
            $args['autoPlay']             = $settings['autoplay_speed'] ? intval( $settings['autoplay_speed'] ) : 1500;
            $args['pauseAutoPlayOnHover'] = isset( $settings['pause_on_hover'] ) && $settings['pause_on_hover'] === 'yes' ? true : false;
        }
        ?>
        <div class="row">
            <div class="col-12">
                <div class="flickity-viewport-visible pt-2 pb-9" data-flickity='<?php echo htmlspecialchars( json_encode($args) ); ?>' data-aos-id="flickity:in" data-aos="1">
                    <?php
                        foreach ( $settings['slides'] as $index => $slide ) :
                            $this->slide_prints_count++;
                            $this->print_slide( $slide, $settings, 'content-slide-' . $index . '-' . $this->slide_prints_count );
                        endforeach;
                    ?>
                </div>
            </div>
        </div>
        <?php
    }
}
