<?php
namespace LandkitElementor\Modules\Device\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

use LandkitElementor;
use LandkitElementor\Base\Base_Widget;
use Elementor\Controls_Manager;
use Elementor\Utils;
// use Elementor\Core\Schemes;
use LandkitElementor\Core\Controls_Manager as LE_Controls_Manager;

/**
 * Landkit Elementor device widget.
 *
 * Landkit Elementor widget that displays a device with the ability to control every
 * aspect of the device design.
 *
 * @since 1.0.0
 */
class Device extends Base_Widget {

    /**
     * Get widget name.
     *
     * Retrieve device widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'lk-device';
    }

    /**
     * Get widget title.
     *
     * Retrieve device widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__( 'Device', 'landkit-elementor' );
    }

    /**
     * Get widget icon.
     *
     * Retrieve device widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-device-laptop';
    }

    /**
     * Get widget keywords.
     *
     * Retrieve the list of keywords the widget belongs to.
     *
     * @since 2.1.0
     * @access public
     *
     * @return array Widget keywords.
     */
    public function get_keywords() {
        return [ 'device' ];
    }

    /**
     * Register device widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function register_controls() {

        $this->start_controls_section(
            'section_device',
            [
                'label' => __( 'Device', 'landkit-elementor' ),
            ]
        );

        $this->add_control(
            'device_skin',
            [
                'label'   => __( 'Skin', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'combo',
                'options' => [
                    'simple'    => __( 'Simple', 'landkit-elementor' ),
                    'combo'     => __( 'Combo', 'landkit-elementor' ),
                    'terminal'  => __( 'Terminal', 'landkit-elementor' ),
                ],
            ]
        );

        $this->add_control(
            'simple_device_type',
            [
                'label'   => __( 'Type', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'iphonex',
                'condition' => [ 'device_skin' => 'simple' ],
                'options' => [
                    'iphonex'   => esc_html__( 'iPhoneX', 'landkit-elementor' ),
                    'macbook'   => esc_html__( 'Macbook', 'landkit-elementor' ),
                ],
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'simple_device_image',
            [
                'label'   => __( 'Choose Image', 'landkit-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [ 'device_skin' => 'simple' ],
            ]
        );

        $this->add_control(
            'simple_device_aos_animation',
            [
                'label'     => __( 'AOS Animation', 'landkit-elementor' ),
                'type'      => LE_Controls_Manager::AOS_ANIMATION,
                'default'   => '',
                'condition' => [ 'device_skin' => 'simple' ],
            ]
        );

        $this->add_control(
            'simple_device_aos_animation_delay',
            [
                'label' => __( 'Animation Delay', 'landkit-elementor' ) . ' (ms)',
                'type' => Controls_Manager::NUMBER,
                'default' => 150,
                'min' => 0,
                'step' => 50,
                'condition' => [
                    'device_skin' => 'simple',
                    'simple_device_aos_animation!' => [ '' , 'none' ],
                ],
                'frontend_available' => true,
            ]
        );

        $this->add_control(
            'combo_device_type',
            [
                'label'   => __( 'Combo Layout', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'macbook-iphonex',
                'condition' => [ 'device_skin' => 'combo' ],
                'options' => [
                    'macbook-iphonex'   => esc_html__( 'Macbook - iPhoneX', 'landkit-elementor' ),
                    'iphonex-iphonex'   => esc_html__( 'iPhoneX - iPhoneX', 'landkit-elementor' ),
                    'iphonex-macbook'   => esc_html__( 'iPhoneX - Macbook', 'landkit-elementor' ),
                ],
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'combo_device_image_1',
            [
                'label'   => __( 'Device 1 Image', 'landkit-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [ 'device_skin' => 'combo' ],
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'combo_device_aos_animation_1',
            [
                'label'   => __( 'Device 1 AOS Animation', 'landkit-elementor' ),
                'type'    => LE_Controls_Manager::AOS_ANIMATION,
                'default' => '',
                'condition' => [ 'device_skin' => 'combo' ],
            ]
        );

        $this->add_control(
            'combo_device_aos_animation_delay_1',
            [
                'label' => __( 'Device 1 Animation Delay', 'landkit-elementor' ) . ' (ms)',
                'type' => Controls_Manager::NUMBER,
                'default' => 150,
                'min' => 0,
                'step' => 50,
                'condition' => [
                    'device_skin' => 'combo',
                    'combo_device_aos_animation_1!' => [ '', 'none'],
                ],
                'frontend_available' => true,
            ]
        );

        $this->add_control(
            'combo_device_image_2',
            [
                'label'   => __( 'Device 2 Image', 'landkit-elementor' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [ 'device_skin' => 'combo' ],
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'combo_device_aos_animation_2',
            [
                'label'   => __( 'Device 2 AOS Animation', 'landkit-elementor' ),
                'type'    => LE_Controls_Manager::AOS_ANIMATION,
                'default' => '',
                'condition' => [ 'device_skin' => 'combo' ],
            ]
        );

        $this->add_control(
            'combo_device_aos_animation_delay_2',
            [
                'label' => __( 'Device 2 Animation Delay', 'landkit-elementor' ) . ' (ms)',
                'type' => Controls_Manager::NUMBER,
                'default' => 150,
                'min' => 0,
                'step' => 50,
                'condition' => [
                    'device_skin' => 'combo',
                    'combo_device_aos_animation_2!' => [ '', 'none'],
                ],
                'frontend_available' => true,
            ]
        );

        $this->add_control(
            'terminal_device_content',
            [
                'label' => __( 'Terminal Content', 'landkit-elementor' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __( '> $ npm install<br/><span class="text-success">Everything is installed</span><br/><br/>> $ gulp<br/><span class="text-success">scss watching</span><br/><span class="text-success">LiveReload started</span><br/><span class="text-success">Opening localhost:3000</span><br/><br/>> $ that’s it<br/><span class="text-success">Yup, that’s it.</span>', 'landkit-elementor' ),
                'condition' => [ 'device_skin' => 'terminal' ],
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'terminal_device_enable_typed',
            [
                'label' => __( 'Enable Typed', 'landkit-elementor' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'frontend_available' => true,
                'condition' => [ 'device_skin' => 'terminal' ],
            ]
        );

        $this->add_control(
            'terminal_device_typed_back_speed',
            [
                'label' => __( 'Typed Back Speed', 'landkit-elementor' ) . ' (sec)',
                'type' => Controls_Manager::NUMBER,
                'default' => 2,
                'min' => 1,
                'min' => 10,
                'step' => 1,
                'condition' => [
                    'device_skin' => 'terminal',
                    'terminal_enable_typed' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'wrapper_additial_css_classes',
            [
                'label'   => __( 'Additional CSS Classes', 'landkit-elementor' ),
                'type'    => Controls_Manager::TEXT,
                'default' => '',
                'separator' => 'before',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_shapes',
            [
                'label' => __( 'Shapes', 'landkit-elementor' ),
                'condition' => [ 'device_skin!' => 'terminal' ],
            ]
        );

        $this->add_control(
            'enable_dividers',
            [
                'label' => __( 'Enable Dividers ?', 'landkit-elementor' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'frontend_available' => true,
            ]
        );

        $this->add_control(
            'dividers',
            [
                'label' => __( 'Dividers', 'landkit-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'curves'   => 'Curves',
                    'wave'     => 'Wave',
                    'angles'   => 'Angles',
                    'blurs'    => 'Blurs',
                ],
                'condition' => [ 'enable_dividers' => 'yes' ],
                'separator' => 'before',
                'default' => 'curves',
            ]
        );

        $this->add_control(
            'curves_styles',
            [
                'label'   => __( 'Curve Styles', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'curve-1',
                'condition' => [ 'enable_dividers' => 'yes', 'dividers' => 'curves' ],
                'options' => [
                    'curve-1'   => 'Curve-1',
                    'curve-2'   => 'Curve-2',
                    'curve-3'   => 'Curve-3',
                    'curve-4'   => 'Curve-4',
                    'curve-5'   => 'Curve-5',
                    'curve-6'   => 'Curve-6',
                ],
            ]
        );

        $this->add_control(
            'angles_styles',
            [
                'label'   => __( 'Angles Styles', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'angle-top',
                'condition' => [ 'enable_dividers' => 'yes', 'dividers' => 'angles' ],
                'options' => [
                    'angle-top'     => 'Angle-1',
                    'angle-bottom'  => 'Angle-2',
                    'angle-right'   => 'Angle-3',
                    'angle-left'    => 'Angle-4',
                ],
            ]
        );

        $this->add_control(
            'blur_styles',
            [
                'label'   => __( 'Blur Styles', 'landkit-elementor' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'blur-1',
                'condition' => [ 'enable_dividers' => 'yes', 'dividers' => 'blurs' ],
                'options' => [
                    'blur-1'   => 'Blur-1',
                    'blur-2'   => 'Blur-2',
                    'blur-3'   => 'Blur-3',
                    'blur-4'   => 'Blur-4',
                ],
            ]
        );

        $this->add_control(
            'shape_color',
            [
                'label' => __( 'Curve Color', 'landkit-elementor' ),
                'type' => Controls_Manager::COLOR,
                // 'scheme' => [
                //     'type' => Schemes\Color::get_type(),
                //     'value' => Schemes\Color::COLOR_2,
                // ],
                'selectors' => [
                    '{{WRAPPER}} .lk-elementor-curve' => 'color: {{VALUE}}',

                ],
                'condition' => [ 'enable_dividers' => 'yes' ],
                'separator' => 'before',
            ]
        );


        $this->add_control(
            'angle_flip',
            [
                'label' => __( 'Angle Flip ?', 'landkit-elementor' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'frontend_available' => true,
                'condition' => [
                    'enable_dividers' => 'yes',
                    'dividers'  => 'angles',
                    'angles_styles' => 'angle-top',
                    'angles_styles' => 'angle-bottom'
                ],
            ]
        );

        $this->add_control(
            'angle_flip_side',
            [
                'label' => __( 'Angle Flip Side', 'landkit-elementor' ),
                'type' => Controls_Manager::SELECT,
                'condition' => [
                    'enable_dividers' => 'yes', 
                    'dividers' => [ 'angles' ],
                    'angle_flip' => [ 'yes' ],
                ],
                'options' => [
                    ''                => 'Default',
                    ' shape-flip-x'   => 'Right',
                    ' shape-flip-y'   => 'Left',
                ],
                'default' => '',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_skewed',
            [
                'label' => __( 'Skewed', 'landkit-elementor' ),
                'condition' => [ 'device_skin' => 'terminal' ],
            ]
        );

        $this->add_control(
            'enable_skewed',
            [
                'label' => __( 'Enable Skewed ?', 'landkit-elementor' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'frontend_available' => true,
            ]
        );

        $this->add_control(
            'skewed_side',
            [
                'label' => __( 'Skewed Side', 'landkit-elementor' ),
                'type' => Controls_Manager::SELECT,
                'condition' => [ 'enable_skewed' => 'yes' ],
                'options' => [
                    'img-skewed-left' => 'Left',
                    'img-skewed-right' => 'Right',
                ],
                'default' => 'img-skewed-right',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render device widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();

        $enable_shapes = isset( $settings['enable_dividers'] ) && $settings['enable_dividers'] === 'yes' ? true : false;

        if( ! empty( $settings['wrapper_additial_css_classes'] ) ) {
            $this->add_render_attribute( 'outter_wrapper', 'class', $settings['wrapper_additial_css_classes'], true );
        }

        if( isset( $settings['device_skin'] ) && $settings['device_skin'] === 'terminal' ) {
            if ( empty( $settings['terminal_device_content'] ) ) {
                return;
            }

            $this->add_render_attribute( 'terminal_device_code', [
                'class' => [ 'highlight', 'hljs' ],
                'style' => 'min-height: 183px;',
            ], true );

            $this->add_render_attribute( 'outter_wrapper', "class", 'elementor-device-terminal-wrapper' );
            $this->add_render_attribute( 'card', "class", [ 'card', 'rounded-lg', 'bg-black', 'mb-6', 'mb-md-0', 'screenshot' ], true );

            if( isset( $settings['enable_skewed'] ) && $settings['enable_skewed'] === 'yes' ) {
                $this->add_render_attribute( 'outter_wrapper', "class", ['img-skewed', $settings['skewed_side'] ] );
                $this->add_render_attribute( 'card', "class", 'img-skewed-item' );
            }

            ?><div <?php echo $this->get_render_attribute_string( 'outter_wrapper' ); ?>>
                <div <?php echo $this->get_render_attribute_string( 'card' ); ?>>
                    <div class="card-header border-white-10">
                        <!-- Controls -->
                        <div class="d-flex">
                            <span class="bg-danger rounded-circle" style="width: 10px; height: 10px;"></span>
                            <span class="bg-warning rounded-circle ml-1" style="width: 10px; height: 10px;"></span>
                            <span class="bg-success rounded-circle ml-1" style="width: 10px; height: 10px;"></span>
                        </div>
                    </div>
                    <div class="card-body">
                        <?php if( $settings['terminal_device_enable_typed'] === 'yes' ) :
                            $dataOptions = array(
                                'backSpeed' => $settings['terminal_device_typed_back_speed'],
                                'strings' => [ $settings['terminal_device_content'] ],
                            );

                            $this->add_render_attribute( 'terminal_device_code', [
                                'data-toggle' => 'typed',
                                'data-options' => htmlspecialchars( json_encode( $dataOptions ), ENT_QUOTES, 'UTF-8' ),
                                'data-aos-id' => 'typed:in',
                                'data-aos' => true,
                            ] );
                            ?>
                            <code <?php echo $this->get_render_attribute_string( 'terminal_device_code' ); ?>></code>
                        <?php else : ?>
                            <code <?php echo $this->get_render_attribute_string( 'terminal_device_code' ); ?>>
                                <?php echo wp_kses_post( $settings['terminal_device_content'] ) ?>
                            </code>
                        <?php endif; ?>
                    </div>
                </div>
            </div><?php
        } elseif( isset( $settings['device_skin'] ) && $settings['device_skin'] === 'combo' ) {
            if ( empty( $settings['combo_device_image_1']['url'] ) || empty( $settings['combo_device_image_2']['url'] ) ) {
                return;
            }

            $combo_device_type = isset( $settings['combo_device_type'] ) ? $settings['combo_device_type'] : 'iphonex-iphonex';
            $combo_device_type_array = explode( "-", $combo_device_type );

            $this->add_render_attribute( 'outter_wrapper', "class", 'elementor-device-combo-wrapper' );

            $this->add_render_attribute( 'combo_wrapper', 'class', 'device-combo device-combo-' . $combo_device_type );

            ?><div <?php echo $this->get_render_attribute_string( 'outter_wrapper' ); ?>><?php
                if( $enable_shapes ) {
                    $this->render_shapes_html( $settings );
                }
                ?><div <?php echo $this->get_render_attribute_string( 'combo_wrapper' ); ?>><?php
                    for ( $i = 1; $i <= 2; $i++ ) {
                        $current_device_type = isset( $combo_device_type_array[$i-1] ) ? $combo_device_type_array[$i-1] : 'iphonex';
                        $frames_ext = apply_filters( 'landkit_elementor_devices_frame_ext_' . $current_device_type, '.svg' );
                        $frames_url = get_theme_file_uri( 'assets/img/devices/' . $current_device_type . $frames_ext );

                        $this->add_render_attribute( "combo_element_wrapper_{$i}", 'class', "elementor-device-wrapper elementor-device-wrapper-{$i} device" );

                        if( ! empty( $settings["combo_device_aos_animation_{$i}"] ) && $settings["combo_device_aos_animation_{$i}"] !== 'none' ) {
                            $this->add_render_attribute( "combo_element_wrapper_{$i}", 'data-aos', $settings["combo_device_aos_animation_{$i}"] );

                            if( ! empty( $settings["combo_device_aos_animation_delay_{$i}"] ) && $settings["combo_device_aos_animation_delay_{$i}"] > 0 ) {
                                $this->add_render_attribute( "combo_element_wrapper_{$i}", 'data-aos-delay', $settings["combo_device_aos_animation_delay_{$i}"] );
                            }
                        }

                        $this->add_render_attribute( "combo_image_{$i}", [
                            'class' => 'device-screen',
                            'src'   => $settings["combo_device_image_{$i}"]['url'],
                            'alt'   => '',
                        ] );

                        $this->add_render_attribute( "combo_image_frame_{$i}", [
                            'class' => 'img-fluid',
                            'alt'   => '', 
                        ] );

                        if ( ! empty( $current_device_type ) ) {
                            $this->add_render_attribute( "combo_element_wrapper_{$i}", 'class', 'device-' . $current_device_type );
                            $this->add_render_attribute( "combo_image_frame_{$i}", 'src', $frames_url );
                        }

                        $this->render_device_html( 'combo_element_wrapper_' . $i, 'combo_image_' . $i, 'combo_image_frame_' . $i );
                    }
                ?></div><?php
            ?></div><?php
        } else {
            if ( empty( $settings['simple_device_image']['url'] ) ) {
                return;
            }

            $this->add_render_attribute( 'outter_wrapper', "class", 'elementor-device-simple-wrapper' );

            $frames_ext = apply_filters( 'landkit_elementor_devices_frame_ext_' . $settings['simple_device_type'], '.svg' );
            $frames_url = get_theme_file_uri( 'assets/img/devices/' . $settings['simple_device_type'] . $frames_ext );

            $this->add_render_attribute( 'simple_element_wrapper', 'class', 'elementor-device-wrapper device' );

            if( ! empty( $settings["simple_device_aos_animation"] ) && $settings["simple_device_aos_animation"] !== 'none' ) {
                $this->add_render_attribute( "simple_element_wrapper", 'data-aos', $settings["simple_device_aos_animation"] );

                if( ! empty( $settings["simple_device_aos_animation_delay"] ) && $settings["simple_device_aos_animation_delay"] > 0 ) {
                    $this->add_render_attribute( "simple_element_wrapper", 'data-aos-delay', $settings["simple_device_aos_animation_delay"] );
                }
            }

            $this->add_render_attribute( "simple_image", [
                'class' => 'device-screen',
                'src'   => $settings['simple_device_image']['url'],
                'alt'   => '',
            ] );

            $this->add_render_attribute( 'simple_image_frame', [
                'class' => 'img-fluid',
                'alt'   => ''
            ] );

            if ( ! empty( $settings['simple_device_type'] ) ) {
                $this->add_render_attribute( 'simple_element_wrapper', 'class', 'device-' . $settings['simple_device_type'] );
                $this->add_render_attribute( 'simple_image_frame', 'src', $frames_url );
            }

            ?><div <?php echo $this->get_render_attribute_string( 'outter_wrapper' ); ?>><?php
                if( $enable_shapes ) {
                    $this->render_shapes_html( $settings );
                }
                $this->render_device_html();
            ?></div><?php
        }
    }

    public function render_device_html( $wrapper_label='simple_element_wrapper', $image_label='simple_image', $image_frame_label='simple_image_frame' ) {
        ?>
        <div <?php echo $this->get_render_attribute_string( $wrapper_label ); ?>>
            <img <?php echo $this->get_render_attribute_string( $image_label ); ?>>
            <img <?php echo $this->get_render_attribute_string( $image_frame_label ); ?>>
        </div>
        <?php
    }

    public function render_shapes_html( $settings ) {
        switch ( $settings['dividers'] ) {
            case 'curves':
                switch ( $settings['curves_styles'] ) {
                    case 'curve-1':
                    case 'curve-2':
                    case 'curve-3':
                    case 'curve-4':
                        ?><div class="shape shape-bottom shape-fluid-x svg-shim lk-elementor-curve"><?php
                            require get_theme_file_path( "assets/img/shapes/curves/{$settings['curves_styles']}.svg" );
                        ?></div><?php
                    break;
                    case 'curve-5':
                        ?><div class="shape shape-right shape-fluid-y svg-shim lk-elementor-curve"><?php 
                            require get_theme_file_path( "assets/img/shapes/curves/{$settings['curves_styles']}.svg" );
                        ?></div><?php
                    break;
                    case 'curve-6':
                        ?><div class="shape shape-left shape-fluid-y svg-shim lk-elementor-curve"><?php
                            require get_theme_file_path( "assets/img/shapes/curves/{$settings['curves_styles']}.svg" );
                        ?></div><?php
                    break;
                } // End switch().
            break;
            case 'wave':
                ?><div class="shape shape-top shape-fluid-x svg-shim lk-elementor-curve"><?php
                    require get_theme_file_path( 'assets/img/shapes/waves/wave-1.svg' );
                ?></div><?php
            break;
            case 'angles':
                switch ( $settings['angles_styles'] ) {
                    case 'angle-top':
                    case 'angle-bottom':
                        ?><div class="shape shape-fluid-x svg-shim lk-elementor-curve <?php echo esc_attr( ( $settings[ 'angle_flip' ] ? $settings[ 'angle_flip_side' ] : '' ) ); echo esc_attr( ' ' . str_replace( 'angle', 'shape', $settings['angles_styles'] ) ); ?>"><?php
                            require get_theme_file_path( "assets/img/shapes/angles/{$settings['angles_styles']}.svg" );
                        ?></div><?php
                    break;
                    case 'angle-right':
                    case 'angle-left':
                        ?><div class="shape shape-fluid-y svg-shim lk-elementor-curve <?php echo esc_attr( str_replace( 'angle', 'shape', $settings['angles_styles'] ) ); ?>"><?php
                            require get_theme_file_path( "assets/img/shapes/angles/{$settings['angles_styles']}.svg" );
                        ?></div><?php
                    break;
                } // End switch().
            break;
            case 'blurs':
                ?><div class="shape svg-shim lk-elementor-curve <?php echo esc_attr( 'shape-' . $settings['blur_styles'] ); ?>"><?php
                    require get_theme_file_path( "assets/img/shapes/blurs/{$settings['blur_styles']}.svg" );
                ?></div><?php
            break;
        }
    }
}
