<?php
namespace LandkitElementor\Modules\PageSettings;

use Elementor\Controls_Manager;
use Elementor\Core\Base\Document;
use Elementor\Core\Base\Module as BaseModule;
use Elementor\Core\DocumentTypes\PageBase;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * Elementor page templates module.
 *
 * Elementor page templates module handler class is responsible for registering
 * and managing Elementor page templates modules.
 *
 * @since 1.0.0
 */
class Module extends BaseModule {

    protected $post_id = 0;
    protected $lk_page_options = [];

    public function __construct() {
        $this->lk_page_options = $this->lk_page_options();
        add_action( 'elementor/documents/register_controls', [ $this, 'action_register_template_control' ] );
        add_action( 'elementor/element/wp-post/section_page_style/before_section_end', [ $this, 'add_body_style_controls' ] );
        add_filter( 'update_post_metadata', [ $this, 'filter_update_meta' ], 10, 5 );
    }

    public function get_name() {
        return 'override-page-settings';
    }

    public function add_body_style_controls( $document ) {
        
        $document->add_control( 'enable_overflow', [
            'label'       => esc_html__( 'Enable Overflow?', 'landkit-elementor' ),
            'type'        => Controls_Manager::SWITCHER,
            'selectors'   => [
                'body' => 'overflow-x:visible !important;'
            ]
        ] );
    }

    public function get_special_settings_names() {
        return [
            // General
            'general_body_classes',

            // Header
            'header_enable_custom_header',
            'header_skin',
            'header_enable_border_bottom',
            'header_enable_bg_transparent',
            'header_enable_navbar_togglable',
            'header_enable_fixed_top',
            'header_enable_header_fullwidth',
            'header_container_layout',
            'header_enable_action_button',
            'header_action_button_link',
            'header_action_button_text',
            'header_action_button_size',
            'header_action_button_background',
            'header_action_button_text_color',
            'header_action_button_background_hover',
            'header_action_button_text_color_hover',

            // Footer
            'footer_disable_footer',
            'footer_enable_custom_footer',
            'footer_background',
            'footer_enable_border_top',
        ];
    }

    public function update_lk_page_option( $object_id, $special_settings ) {
        $_lk_page_options = $this->lk_page_options( $object_id );
        $lk_page_options = ! empty( $_lk_page_options ) ? $_lk_page_options : [] ;

        $general_option_key = 'general';
        $header_option_key = 'header';
        $footer_option_key = 'footer';
        $len_general_option_key = strlen( $general_option_key . '_' );
        $len_header_option_key = strlen( $header_option_key . '_' );
        $len_footer_option_key = strlen( $footer_option_key . '_' );

        foreach ( $special_settings as $key => $value ) {
            if( substr( $key, 0, $len_general_option_key ) === $general_option_key . '_' ) {
                if( ! isset( $lk_page_options[$general_option_key] ) ) {
                    $lk_page_options[$general_option_key] = [];
                }
                $lk_page_options[$general_option_key][substr($key, $len_general_option_key)] = $value;
            } elseif( substr( $key, 0, $len_header_option_key ) === $header_option_key . '_' ) {
                if( ! isset( $lk_page_options[$header_option_key] ) ) {
                    $lk_page_options[$header_option_key] = [];
                }
                $lk_page_options[$header_option_key][substr($key, $len_header_option_key)] = $value;
            } elseif( substr( $key, 0, $len_footer_option_key ) === $footer_option_key . '_' ) {
                if( ! isset( $lk_page_options[$footer_option_key] ) ) {
                    $lk_page_options[$footer_option_key] = [];
                }
                $lk_page_options[$footer_option_key][substr($key, $len_footer_option_key)] = $value;
            } else {
                $lk_page_options[$key] = $value;
            }
        }

        if( ! empty( $lk_page_options ) ) {
            $this->lk_page_options = $lk_page_options;
            update_metadata( 'post', $object_id, '_lk_page_options', $lk_page_options );
        }
    }

    public function get_lk_page_options( $option_name, $option_group='', $dafault='' ) {
        $lk_page_options = $this->lk_page_options();

        if( ! empty( $option_group ) && ! empty( $option_name ) ) {
            if( isset( $lk_page_options[$option_group] ) && isset( $lk_page_options[$option_group][$option_name] ) ) {
                return $lk_page_options[$option_group][$option_name];
            }
        } elseif( empty( $option_group ) && ! empty( $option_name ) ) {
            if( isset( $lk_page_options[$option_name] ) ) {
                return $lk_page_options[$option_name];
            }
        }
        return $dafault;
    }

    public function lk_page_options( $post_id=null ) {
        if( ! empty( $this->lk_page_options ) ) {
            return $this->lk_page_options;
        }

        if( ! $post_id ) {
            $post_id = $this->post_id;
        }

        $clean_meta_data = get_post_meta( $post_id, '_lk_page_options', true );
        $lk_page_options = maybe_unserialize( $clean_meta_data );

        if( empty( $lk_page_options ) ) {
            $lk_page_options = [];
        } elseif ( ! empty( $lk_page_options ) && ! is_array( $lk_page_options ) ) {
            $lk_page_options = [];
        }

        $this->lk_page_options = $lk_page_options;
        return $lk_page_options;
    }

    /**
     * Register template control.
     *
     * Adds custom controls to any given document.
     *
     * Fired by `update_post_metadata` action.
     *
     * @since 1.0.0
     * @access public
     *
     * @param Document $document The document instance.
     */
    public function action_register_template_control( $document ) {
        $post_types = function_exists( 'landkit_option_enabled_post_types' ) ? landkit_option_enabled_post_types() : ['post', 'page'];
        if ( $document instanceof PageBase && is_a( $document->get_main_post(), 'WP_Post') && in_array( $document->get_main_post()->post_type, $post_types ) ) {
            $this->post_id = $document->get_main_post()->ID;
            $this->register_template_control( $document );
        }
    }

    /**
     * Register template control.
     *
     * Adds custom controls to any given document.
     *
     * @since 1.0.0
     * @access public
     *
     * @param Document $page   The document instance.
     * @param string   $option_group Optional.
     */
    public function register_template_control( $page ) {
        $this->add_general_controls( $page, 'general' );
        $this->add_header_controls( $page, 'header' );
        $this->add_footer_controls( $page, 'footer' );
    }

    public function add_general_controls( Document $page, $option_group='' ) {
        $page->start_injection( [
            'of' => 'post_status',
            'fallback' => [
                'of' => 'post_title',
            ],
        ] );

        $page->add_control(
            'general_body_classes', [
                'label'     => esc_html__( 'Body Classes', 'landkit-elementor' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => $this->get_lk_page_options( 'body_classes', $option_group ),
            ]
        );

        $page->end_injection();
    }

    public function add_header_controls( Document $page, $option_group='' ) {
        $page->start_controls_section(
            'document_settings_header', [
                'label'     => esc_html__( 'Headers', 'landkit-elementor' ),
                'tab'       => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $page->add_control(
            'header_enable_custom_header', [
                'label'     => esc_html__( 'Custom Header', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => $this->get_lk_page_options( 'enable_custom_header', 'header' ),
                'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
            ]
        );

        $page->add_control(
            'header_skin', [
                'label'     => esc_html__( 'Skin', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'light' => esc_html__( 'Light', 'landkit-elementor'),
                    'dark'  => esc_html__( 'Dark', 'landkit-elementor'),
                ],
                'condition' => [
                    'header_enable_custom_header'   => 'yes',
                ],
                'default'   => $this->get_lk_page_options( 'skin', $option_group, 'light' ),
            ]
        );

        $page->add_control(
            'header_enable_bg_transparent', [
                'label'     => esc_html__( 'Transparent Backgorund', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => $this->get_lk_page_options( 'enable_bg_transparent', $option_group ),
                'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
                'condition' => [
                    'header_enable_custom_header'   => 'yes',
                ],
            ]
        );

        $page->add_control(
            'header_enable_border_bottom', [
                'label'     => esc_html__( 'Border Bottom', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => $this->get_lk_page_options( 'enable_border_bottom', $option_group ),
                'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
                'condition' => [
                    'header_enable_custom_header'   => 'yes',
                    'header_skin'                   => 'light',
                ],
            ]
        );

        $page->add_control(
            'header_enable_navbar_togglable', [
                'label'     => esc_html__( 'Navbar Togglable', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => $this->get_lk_page_options( 'enable_navbar_togglable', $option_group ),
                'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
                'condition' => [
                    'header_enable_custom_header'   => 'yes',
                    'header_skin'                   => 'dark',
                ],
            ]
        );

        $page->add_control(
            'header_enable_fixed_top', [
                'label'     => esc_html__( 'Fixed Top', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => $this->get_lk_page_options( 'enable_fixed_top', $option_group ),
                'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
                'condition' => [
                    'header_enable_custom_header'   => 'yes',
                ],
            ]
        );

        $page->add_control(
            'header_enable_header_fullwidth', [
                'label'     => esc_html__( 'Make Fullwidth ?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => $this->get_lk_page_options( 'enable_header_fullwidth', $option_group ),
                'label_on'  => esc_html__( 'Yes', 'landkit-elementor' ),
                'label_off' => esc_html__( 'No', 'landkit-elementor' ),
                'condition' => [
                    'header_enable_custom_header'   => 'yes',
                ],
            ]
        );

        $page->add_control(
            'header_container_layout', [
                'label'     => esc_html__( 'Container Layout', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'container'     => esc_html__( 'Default', 'landkit-elementor' ),
                    'container-sm'  => esc_html__( 'Container Small', 'landkit-elementor' ),
                    'container-md'  => esc_html__( 'Container medium ', 'landkit-elementor' ),
                    'container-lg'  => esc_html__( 'Container Large ', 'landkit-elementor' ),
                    'container-xl'  => esc_html__( 'Container Extra Large', 'landkit-elementor' ),
                ],
                'condition' => [
                    'header_enable_custom_header'       => 'yes',
                    'header_enable_header_fullwidth'    => 'yes',
                ],
                'default'   => $this->get_lk_page_options( 'container_layout', $option_group, 'light' ),
            ]
        );

        $page->add_control(
            'header_enable_action_button', [
                'label'     => esc_html__( 'Display Button ?', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => $this->get_lk_page_options( 'enable_action_button', $option_group ),
                'label_on'  => esc_html__( 'Show', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Hide', 'landkit-elementor' ),
                'condition' => [
                    'header_enable_custom_header'   => 'yes',
                ],
            ]
        );

        // $page->add_control(
        //     'header_action_button_link', [
        //         'label'     => esc_html__( 'Button Link', 'landkit-elementor' ),
        //         'type'      => Controls_Manager::TEXT,
        //         'default'   => $this->get_lk_page_options( 'action_button_link', $option_group, '#' ),
        //         'condition' => [
        //             'header_enable_custom_header'   => 'yes',
        //             'header_enable_action_button'   => 'yes',
        //         ],
        //     ]
        // );

        // $page->add_control(
        //     'header_action_button_text', [
        //         'label'     => esc_html__( 'Button Text', 'landkit-elementor' ),
        //         'type'      => Controls_Manager::TEXT,
        //         'default'   => $this->get_lk_page_options( 'action_button_text', $option_group, esc_html__( 'Buy now', 'landkit-elementor' ) ),
        //         'condition' => [
        //             'header_enable_custom_header'   => 'yes',
        //             'header_enable_action_button'   => 'yes',
        //         ],
        //     ]
        // );

        // $page->add_control(
        //     'header_action_button_size', [
        //         'label'     => esc_html__( 'Button Size', 'landkit-elementor' ),
        //         'type'      => Controls_Manager::SELECT,
        //         'options'   => [
        //             ''          => esc_html__( 'Default', 'landkit-elementor'),
        //             'btn-xs'    => esc_html__( 'Extra Small', 'landkit-elementor'),
        //             'btn-sm'    => esc_html__( 'Small', 'landkit-elementor'),
        //             'btn-lg'    => esc_html__( 'Large', 'landkit-elementor'),
        //         ],
        //         'condition' => [
        //             'header_enable_custom_header'   => 'yes',
        //             'header_enable_action_button'   => 'yes',
        //         ],
        //         'default'   => $this->get_lk_page_options( 'action_button_size', $option_group ),
        //     ]
        // );

        // $page->add_control(
        //     'header_action_button_background', [
        //         'label'     => esc_html__( 'Button Background', 'landkit-elementor' ),
        //         'type'      => Controls_Manager::COLOR,
        //         'condition' => [
        //             'header_enable_custom_header'   => 'yes',
        //             'header_enable_action_button'   => 'yes',
        //         ],
        //         'default'   => $this->get_lk_page_options( 'action_button_background', $option_group, '#133bbd' ),
        //     ]
        // );

        // $page->add_control(
        //     'header_action_button_text_color', [
        //         'label'     => esc_html__( 'Button Text Color', 'landkit-elementor' ),
        //         'type'      => Controls_Manager::COLOR,
        //         'condition' => [
        //             'header_enable_custom_header'   => 'yes',
        //             'header_enable_action_button'   => 'yes',
        //         ],
        //         'default'   => $this->get_lk_page_options( 'action_button_text_color', $option_group, '#FFFFFF' ),
        //     ]
        // );

        // $page->add_control(
        //     'header_action_button_background_hover', [
        //         'label'     => esc_html__( 'Button Background Hover', 'landkit-elementor' ),
        //         'type'      => Controls_Manager::COLOR,
        //         'condition' => [
        //             'header_enable_custom_header'   => 'yes',
        //             'header_enable_action_button'   => 'yes',
        //         ],
        //         'default'   => $this->get_lk_page_options( 'action_button_background_hover', $option_group, '#1746e0' ),
        //     ]
        // );

        // $page->add_control(
        //     'header_action_button_text_color_hover', [
        //         'label'     => esc_html__( 'Button Text Color Hover', 'landkit-elementor' ),
        //         'type'      => Controls_Manager::COLOR,
        //         'condition' => [
        //             'header_enable_custom_header'   => 'yes',
        //             'header_enable_action_button'   => 'yes',
        //         ],
        //         'default'   => $this->get_lk_page_options( 'action_button_text_color_hover', $option_group, '#FFFFFF' ),
        //     ]
        // );

        $page->end_controls_section();
    }

    public function add_footer_controls( Document $page, $option_group='' ) {
        $page->start_controls_section(
            'document_settings_footer', [
                'label'     => esc_html__( 'Footer', 'landkit-elementor' ),
                'tab'       => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $page->add_control(
            'footer_disable_footer', [
                'label'     => esc_html__( 'Disable Footer', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => $this->get_lk_page_options( 'disable_footer', $option_group ),
                'label_on'  => esc_html__( 'Yes', 'landkit-elementor' ),
                'label_off' => esc_html__( 'No', 'landkit-elementor' ),
            ]
        );

        $page->add_control(
            'footer_enable_custom_footer', [
                'label'     => esc_html__( 'Custom Footer', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => $this->get_lk_page_options( 'enable_custom_footer', $option_group ),
                'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
                'condition' => [
                    'footer_disable_footer!'    => 'yes',
                ],
            ]
        );

        $page->add_control(
            'footer_background', [
                'label'     => esc_html__( 'Skin', 'landkit-elementor' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'bg-gray-200'   => esc_html__( 'Gray 200', 'landkit-elementor'),
                    'bg-white'      => esc_html__( 'White', 'landkit-elementor'),
                    'bg-dark'       => esc_html__( 'Dark', 'landkit-elementor'),
                    'bg-black'      => esc_html__( 'Black', 'landkit-elementor'),
                    'bg-light'      => esc_html__( 'Light', 'landkit-elementor'),
                ],
                'condition' => [
                    'footer_disable_footer!'        => 'yes',
                    'footer_enable_custom_footer'   => 'yes',
                ],
                'default'   => $this->get_lk_page_options( 'background', $option_group, 'bg-gray-200' ),
            ]
        );

        $page->add_control(
            'footer_enable_border_top', [
                'label'     => esc_html__( 'Border Top', 'landkit-elementor' ),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => $this->get_lk_page_options( 'enable_border_top', $option_group ),
                'label_on'  => esc_html__( 'Enable', 'landkit-elementor' ),
                'label_off' => esc_html__( 'Disable', 'landkit-elementor' ),
                'condition' => [
                    'footer_disable_footer!'        => 'yes',
                    'footer_enable_custom_footer'   => 'yes',
                ],
            ]
        );

        $page->end_controls_section();
    }

    /**
     * Filter metadata update.
     *
     * Filters whether to update metadata of a specific type.
     *
     * Elementor don't allow WordPress to update the parent page template
     * during `wp_update_post`.
     *
     * Fired by `update_{$meta_type}_metadata` filter.
     *
     * @since 1.0.0
     * @access public
     *
     * @param bool   $check     Whether to allow updating metadata for the given type.
     * @param int    $object_id Object ID.
     * @param string $meta_key  Meta key.
     *
     * @return bool Whether to allow updating metadata of a specific type.
     */
    public function filter_update_meta( $check, $object_id, $meta_key, $meta_value, $prev_value ) {
        if ( '_elementor_page_settings' === $meta_key ) {
            $current_check = $check;
            if ( ! empty( $meta_value ) && is_array( $meta_value ) ) {
                $special_settings_names = $this->get_special_settings_names();
                $special_settings = [];
                foreach ( $special_settings_names as $name ) {
                    if( isset( $meta_value[$name] ) ) {
                        $special_settings[$name] = $meta_value[$name];
                        unset(  $meta_value[$name] );
                        $current_check = false;
                    }
                }
                if( $current_check === false ) {
                    update_metadata( 'post', $object_id, $meta_key, $meta_value, $prev_value );
                    $this->update_lk_page_option( $object_id, $special_settings );
                    return $current_check;
                }
            }
        }

        return $check;
    }
}
