<?php

namespace LandkitElementor\Modules\Section;

use LandkitElementor\Base\Module_Base;
use Elementor\Controls_Manager;
use Elementor\Plugin;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

class Module extends Module_Base {

    public function __construct() {
        parent::__construct();

        $this->add_actions();
    }

    public function get_name() {
        return 'override-section';
    }

    public function add_actions() {
        add_action( 'elementor/frontend/section/before_render', [ $this, 'before_render' ], 5 );
        add_action( 'elementor/frontend/section/after_render', [ $this, 'after_render' ], 5 );
        add_action( 'elementor/element/section/section_layout/before_section_end', [ $this, 'add_modal_controls' ], 10 );
        add_action( 'elementor/element/section/section_advanced/before_section_end', [ $this, 'add_section_controls' ], 10, 2 );
        add_action( 'elementor/element/section/section_shape_divider/before_section_end', [ $this, 'shape_divider_controls' ], 10, 2 );
        add_filter( 'elementor/section/print_template', [ $this, 'print_template' ] );
    }

    public function shape_divider_controls( $element, $args ) {
        $element->update_control(
            'shape_divider_top_color', [
                'selectors' => [
                    "{{WRAPPER}} > .elementor-shape-top .elementor-shape-fill" => 'fill: {{UNIT}};',
                    "{{WRAPPER}} > .elementor-shape-top" => 'color: {{UNIT}};',
                ],
            ]
        );
        $element->update_control(
            'shape_divider_bottom_color', [
                'selectors' => [
                    "{{WRAPPER}} > .elementor-shape-bottom .elementor-shape-fill" => 'fill: {{UNIT}};',
                    "{{WRAPPER}} > .elementor-shape-bottom" => 'color: {{UNIT}};',
                ],
            ]
        );
    }

    public function print_template( $content ) {
        ob_start();
        $this->content_template();
        return ob_get_clean();
    }

    public function content_template() {
        ?><#
        if ( 'no' == settings.gap ) {
            settings.gap = settings.gap + ' no-gutters';
        }

        if ( '' !== settings.container_class ) {
            settings.gap = settings.gap + ' ' + settings.container_class;
        }

        view.addRenderAttribute( 'background-between', {
            'class': 'elementor-background-between elementor-background-holder',
        } );

        if ( settings.double_image_1.url != '' || settings.double_image_2.url != '' ) {
            view.addRenderAttribute( 'background-between', {
                'class': 'bg-between',
            } );

            const imageOne = settings.double_image_1.url != '' ? `url( ${ settings.double_image_1.url } )` : '';
            const seperator = ( settings.double_image_1.url != '' &&  settings.double_image_2.url != '' ) ? ', ' : '';
            const imageTwo = settings.double_image_2.url != '' ? `url( ${ settings.double_image_2.url } )` : '';

            view.addRenderAttribute( 'background-between', {
                'style': `background-image: ${ imageOne }${ seperator }${ imageTwo }`
            } );
        }

        if ( settings.background_video_link ) {
            let videoAttributes = 'autoplay muted playsinline';

            if ( ! settings.background_play_once ) {
                videoAttributes += ' loop';
            }

            view.addRenderAttribute( 'background-video-container', 'class', 'elementor-background-video-container' );

            if ( ! settings.background_play_on_mobile ) {
                view.addRenderAttribute( 'background-video-container', 'class', 'elementor-hidden-phone' );
            }
        #>
            <div {{{ view.getRenderAttributeString( 'background-video-container' ) }}}>
                <div class="elementor-background-video-embed"></div>
                <video class="elementor-background-video-hosted elementor-html5-video" {{ videoAttributes }}></video>
            </div>
        <# } #>
        <div {{{ view.getRenderAttributeString( 'background-between' ) }}}></div>
        <div class="elementor-background-overlay"></div>
        <div class="elementor-shape elementor-shape-top"></div>
        <div class="elementor-shape elementor-shape-bottom"></div>
        <div class="elementor-container elementor-column-gap-{{ settings.gap }}">
            <?php if ( Plugin::$instance->experiments->is_feature_active( 'elementWrappers' ) ) { ?>
                <div class="elementor-row"></div>
            <?php } ?>
        </div>
        <?php
    }

    public function add_modal_controls( $element ) {
        $element->add_control( 'enable_modal', [
            'label'       => esc_html__( 'Enable Modal', 'landkit-elementor' ),
            'type'        => Controls_Manager::SWITCHER,
            'description' => esc_html__( 'Enable this option if you want to render this section inside a modal box', 'landkit-elementor' ),
            'separator'   => 'before',
        ] );

        $element->add_control( 'modal_size', [
            'label'       => esc_html__( 'Modal Box Size', 'landkit-elementor' ),
            'type'        => Controls_Manager::SELECT,
            'options'     => [
                ''   => esc_html__( 'Default', 'landkit-elementor' ),
                'lg' => esc_html__( 'Large', 'landkit-elementor' ),
            ],
            'default'     => 'lg',
            'condition'   => [ 'enable_modal' => 'yes' ]
        ] );

        $element->add_control( 'modal_id', [
            'label'       => esc_html__( 'Modal ID', 'landkit-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'description' => esc_html__( 'Give an unique ID for your modal box. You can use this ID with button to trigger the modal box.', 'landkit-elementor' ),
            'condition'   => [ 'enable_modal' => 'yes' ]
        ] );

        $element->add_control( 'aria_labelledby', [
            'label'       => esc_html__( 'Labelled By', 'landkit-elementor' ),
            'type'        => Controls_Manager::TEXT,
            'description' => esc_html__( 'ID of the heading element of the modal box. This is for ARIA.', 'landkit-elementor' ),
            'condition'   => [ 'enable_modal' => 'yes' ]
        ] );
    }

    public function add_section_controls( $element, $args ) {
        $element->add_control(
            'container_class',
            [
                'label'        => esc_html__( 'Container CSS Classes', 'landkit-elementor' ),
                'label_block'  => true,
                'type'         => Controls_Manager::TEXT,
                'description'  => esc_html__( 'Applied to elementor-container element. You can use additional bootstrap utility classes here.', 'landkit-elementor' ),
            ]
        );        
    }

    public function before_render( $element ) {
        $settings        = $element->get_settings();
        $container_class = $settings['gap'];
        
        if ( 'no' === $settings['gap'] ) {
            $container_class = $settings['gap'] . ' no-gutters';
        }

        if ( isset( $settings['container_class'] ) && ! empty( $settings['container_class'] ) ) {
            $container_class .= ' ' . $settings['container_class'];
        }

        if ( ! empty( $container_class ) ) {
            $element->set_settings( 'gap', $container_class );           
        }

        if ( ! empty( $settings[ 'shape_divider_top' ] ) || ! empty( $settings[ 'shape_divider_bottom'] ) ) {
            $top = [];
            if ( ! empty( $settings[ 'shape_divider_top' ] ) ) {
                $top = $this->get_shape_classes( $settings[ 'shape_divider_top'] );
            }

            $bottom = [];
            if ( ! empty( $settings[ 'shape_divider_bottom' ] ) ) {
                $bottom = $this->get_shape_classes( $settings[ 'shape_divider_bottom'] );
            }

            $shape_classes = array_merge( $top, $bottom );

            $element->add_render_attribute( '_wrapper', 'class', $shape_classes );
        }

        if ( isset( $settings['enable_modal'] ) && 'yes' === $settings['enable_modal'] ) {
            
            $modal_id        = $settings['modal_id'];
            $aria_labelledby = $settings['aria_labelledby'];
            $modal_size      = $settings['modal_size'];
            
            $element->add_render_attribute( 'modal', [
                'class'       => [ 'modal', 'fade' ],
                'tabindex'    => '-1',
                'role'        => 'dialog',
                'aria-hidden' => 'true'
            ] );

            if ( ! empty( $modal_id ) ) {
                $element->add_render_attribute( 'modal', 'id', $modal_id );
            }

            if ( ! empty( $aria_labelledby ) ) {
                $element->add_render_attribute( 'modal', 'aria-labelledby', $aria_labelledby );   
            }

            $element->add_render_attribute( 'modal_dialog', [
                'class' => [ 'modal-dialog', 'modal-dialog-centered' ],
                'role'  => 'document'
            ] );

            if ( ! empty( $modal_size ) ) {
                $element->add_render_attribute( 'modal_dialog', 'class', 'modal-' . $modal_size );
            }

            ?><div <?php echo $element->get_render_attribute_string( 'modal' ); ?>>
                <div <?php echo $element->get_render_attribute_string( 'modal_dialog' ); ?>>
                    <div class="modal-content"><?php
        }
    }

    public function after_render( $section ) {
        $settings = $section->get_settings();
        if ( isset( $settings['enable_modal'] ) && 'yes' === $settings['enable_modal'] ) {
                    ?></div>
                </div>
            </div><?php
        }
    }

    private function get_shape_classes( $shape_divider ) {
        $classes = [ 'lk-shape' ];

        switch( $shape_divider ) {
            case 'landkit-curve-1':
            case 'landkit-curve-2':
            case 'landkit-curve-3':
            case 'landkit-curve-6':
                $classes[] = 'lk-shape-bottom';
                $classes[] = 'lk-shape-fluid-x';
            break;
            case 'landkit-curve-4':
                $classes[] = 'lk-shape-right';
                $classes[] = 'lk-shape-fluid-y';
            break;
            case 'landkit-curve-5':
                $classes[] = 'lk-shape-left';
                $classes[] = 'lk-shape-fluid-y';
            break;
            case 'landkit-wave':
                $classes[] = 'lk-shape-top';
                $classes[] = 'lk-shape-fluid-x';
            break;
            case 'landkit-angle-right':
                $classes[] = 'lk-shape-right';
                $classes[] = 'lk-shape-fluid-y';
            break;
            case 'landkit-angle-left':
                $classes[] = 'lk-shape-left';
                $classes[] = 'lk-shape-fluid-y';
            break;
            case 'landkit-angle-top':
                $classes[] = 'lk-shape-top';
                $classes[] = 'lk-shape-fluid-x';
            break;
            case 'landkit-angle-top-flip':
                $classes[] = 'lk-shape-top';
                $classes[] = 'lk-shape-fluid-x';
                $classes[] = 'lk-shape-flip-x';
            break;
            case 'landkit-angle-bottom':
                $classes[] = 'lk-shape-bottom';
                $classes[] = 'lk-shape-fluid-x';
            break;
            case 'landkit-angle-bottom-flip':
                $classes[] = 'lk-shape-bottom';
                $classes[] = 'lk-shape-fluid-x';
                $classes[] = 'lk-shape-flip-x';
            break;
            case 'landkit-blur-1':
                $classes[] = 'lk-shape-blur-1';
            break;
            case 'landkit-blur-2':
                $classes[] = 'lk-shape-blur-2';
            break;
            case 'landkit-blur-3':
                $classes[] = 'lk-shape-blur-3';
            break;
            case 'landkit-blur-4':
                $classes[] = 'lk-shape-blur-4';
        }

        return $classes;
    }
}