<?php
/**
 * landkit Meta Box Functions
 *
 * @author      MadrasThemes
 * @category    Core
 * @package     landkitExtensions/Admin/Functions
 * @version     2.3.0
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

/**
 * Output a text input box.
 *
 * @param array $field
 */
function landkit_wp_text_input( $field ) {
    global $thepostid, $post;

    $thepostid              = empty( $thepostid ) ? $post->ID : $thepostid;
    $field['placeholder']   = isset( $field['placeholder'] ) ? $field['placeholder'] : '';
    $field['class']         = isset( $field['class'] ) ? $field['class'] : 'short';
    $field['style']         = isset( $field['style'] ) ? $field['style'] : '';
    $field['wrapper_class'] = isset( $field['wrapper_class'] ) ? $field['wrapper_class'] : '';
    $field['value']         = isset( $field['value'] ) ? $field['value'] : get_post_meta( $thepostid, $field['id'], true );
    $field['name']          = isset( $field['name'] ) ? $field['name'] : $field['id'];
    $field['type']          = isset( $field['type'] ) ? $field['type'] : 'text';
    $field['desc_tip']      = isset( $field['desc_tip'] ) ? $field['desc_tip'] : false;
    $data_type              = empty( $field['data_type'] ) ? '' : $field['data_type'];

    switch ( $data_type ) {
        case 'decimal':
            $field['class'] .= ' wc_input_decimal';
            $field['value']  = landkit_format_localized_decimal( $field['value'] );
            break;
        case 'url':
            $field['class'] .= ' wc_input_url';
            $field['value']  = esc_url( $field['value'] );
            break;
        default:
            break;
    }

    // Custom attribute handling
    $custom_attributes = array();

    if ( ! empty( $field['custom_attributes'] ) && is_array( $field['custom_attributes'] ) ) {

        foreach ( $field['custom_attributes'] as $attribute => $value ) {
            $custom_attributes[] = esc_attr( $attribute ) . '="' . esc_attr( $value ) . '"';
        }
    }

    echo '<p class="form-field ' . esc_attr( $field['id'] ) . '_field ' . esc_attr( $field['wrapper_class'] ) . '">
        <label for="' . esc_attr( $field['id'] ) . '">' . wp_kses_post( $field['label'] ) . '</label>';

    if ( ! empty( $field['description'] ) && false !== $field['desc_tip'] ) {
        echo landkit_help_tip( $field['description'] );
    }

    echo '<input type="' . esc_attr( $field['type'] ) . '" class="' . esc_attr( $field['class'] ) . '" style="' . esc_attr( $field['style'] ) . '" name="' . esc_attr( $field['name'] ) . '" id="' . esc_attr( $field['id'] ) . '" value="' . esc_attr( $field['value'] ) . '" placeholder="' . esc_attr( $field['placeholder'] ) . '" ' . implode( ' ', $custom_attributes ) . ' /> ';

    if ( ! empty( $field['description'] ) && false === $field['desc_tip'] ) {
        echo '<span class="description">' . wp_kses_post( $field['description'] ) . '</span>';
    }

    echo '</p>';
}

/**
 * Output a hidden input box.
 *
 * @param array $field
 */
function landkit_wp_hidden_input( $field ) {
    global $thepostid, $post;

    $thepostid      = empty( $thepostid ) ? $post->ID : $thepostid;
    $field['value'] = isset( $field['value'] ) ? $field['value'] : get_post_meta( $thepostid, $field['id'], true );
    $field['class'] = isset( $field['class'] ) ? $field['class'] : '';

    echo '<input type="hidden" class="' . esc_attr( $field['class'] ) . '" name="' . esc_attr( $field['id'] ) . '" id="' . esc_attr( $field['id'] ) . '" value="' . esc_attr( $field['value'] ) . '" /> ';
}


/**
 * Output a select input box.
 *
 * @param array $field Data about the field to render.
 */
function landkit_wp_select( $field ) {
    global $thepostid, $post;

    $thepostid = empty( $thepostid ) ? $post->ID : $thepostid;
    $field     = wp_parse_args(
        $field, array(
            'class'             => 'select short',
            'style'             => '',
            'wrapper_class'     => '',
            'value'             => get_post_meta( $thepostid, $field['id'], true ),
            'name'              => $field['id'],
            'desc_tip'          => false,
            'custom_attributes' => array(),
        )
    );

    $wrapper_attributes = array(
        'class' => $field['wrapper_class'] . " form-field {$field['id']}_field",
    );

    $label_attributes = array(
        'for' => $field['id'],
    );

    $field_attributes          = (array) $field['custom_attributes'];
    $field_attributes['style'] = $field['style'];
    $field_attributes['id']    = $field['id'];
    $field_attributes['name']  = $field['name'];
    $field_attributes['class'] = $field['class'];

    $tooltip     = ! empty( $field['description'] ) && false !== $field['desc_tip'] ? $field['description'] : '';
    $description = ! empty( $field['description'] ) && false === $field['desc_tip'] ? $field['description'] : '';
    ?>
    <p <?php echo landkit_implode_html_attributes( $wrapper_attributes ); // WPCS: XSS ok. ?>>
        <label <?php echo landkit_implode_html_attributes( $label_attributes ); // WPCS: XSS ok. ?>><?php echo wp_kses_post( $field['label'] ); ?></label>
    
        <select <?php echo landkit_implode_html_attributes( $field_attributes ); // WPCS: XSS ok. ?>>
            <?php
            foreach ( $field['options'] as $key => $value ) {
                echo '<option value="' . esc_attr( $key ) . '"' . landkit_selected( $key, $field['value'] ) . '>' . esc_html( $value ) . '</option>';
            }
            ?>
        </select>
        <?php if ( $description ) : ?>
            <span class="description"><?php echo wp_kses_post( $description ); ?></span>
        <?php endif; ?>
    </p>
    <?php
}

/**
 * Output a checkbox input box.
 *
 * @param array $field
 */
function landkit_wp_checkbox( $field ) {
    global $thepostid, $post;

    $thepostid              = empty( $thepostid ) ? $post->ID : $thepostid;
    $field['class']         = isset( $field['class'] ) ? $field['class'] : 'checkbox';
    $field['style']         = isset( $field['style'] ) ? $field['style'] : '';
    $field['wrapper_class'] = isset( $field['wrapper_class'] ) ? $field['wrapper_class'] : '';
    $field['value']         = isset( $field['value'] ) ? $field['value'] : get_post_meta( $thepostid, $field['id'], true );
    $field['cbvalue']       = isset( $field['cbvalue'] ) ? $field['cbvalue'] : 'yes';
    $field['name']          = isset( $field['name'] ) ? $field['name'] : $field['id'];

    // Custom attribute handling
    $custom_attributes = array();

    if ( ! empty( $field['custom_attributes'] ) && is_array( $field['custom_attributes'] ) ) {

        foreach ( $field['custom_attributes'] as $attribute => $value ){
            $custom_attributes[] = esc_attr( $attribute ) . '="' . esc_attr( $value ) . '"';
        }
    }

    echo '<p class="form-field ' . esc_attr( $field['id'] ) . '_field ' . esc_attr( $field['wrapper_class'] ) . '"><input type="checkbox" class="' . esc_attr( $field['class'] ) . '" style="' . esc_attr( $field['style'] ) . '" name="' . esc_attr( $field['name'] ) . '" id="' . esc_attr( $field['id'] ) . '" value="' . esc_attr( $field['cbvalue'] ) . '" ' . checked( $field['value'], $field['cbvalue'], false ) . '  ' . implode( ' ', $custom_attributes ) . '/><label for="' . esc_attr( $field['id'] ) . '">' . wp_kses_post( $field['label'] ) . '</label>';

    if ( ! empty( $field['description'] ) ) {
        echo '<span class="description">' . wp_kses_post( $field['description'] ) . '</span>';
    }

    echo '</p>';
}

/**
 * Output a image upload field.
 *
 * @param array $field
 */
function landkit_wp_upload_image( $field ) {
    global $thepostid, $post;

    $placeholder = plugins_url( '/assets/img/placeholder.png', LANDKIT_PLUGIN_FILE );

    $thepostid              = empty( $thepostid ) ? $post->ID : $thepostid;
    $field['name']          = isset( $field['name'] ) ? $field['name'] : $field['id'];
    $field['value']         = isset( $field['value'] ) ? $field['value'] : get_post_meta( $thepostid, $field['id'], true );
    $field['wrapper_class'] = isset( $field['wrapper_class'] ) ? $field['wrapper_class'] : '';
    $field['placeholder']   = isset( $field['placeholder'] ) ? $field['placeholder'] : false;

    if ( absint( $field['value'] ) ) {
        $image = wp_get_attachment_image_url( $field['value'], 'medium' );
    } elseif ( $field['placeholder'] ) {
        $image = $placeholder;
    } else {
        $image = '';
    }

    echo '<div id="' . esc_attr( $field['id'] ) . '_field" class="form-field media-option media-upload-field ' . esc_attr( $field['id'] ) . '_field ' . esc_attr( $field['wrapper_class'] ) . '"><label for="' . esc_attr( $field['id'] ) . '">' . wp_kses_post( $field['label'] ) . '</label>';
    ?>
        <?php if ( isset ( $image ) ) : ?>
            <div style="text-align: center;"><img src="<?php echo esc_attr( $image ); ?>" class="upload_image_preview" data-placeholder-src="<?php echo esc_attr( $placeholder ); ?>" alt="" /></div>
        <?php endif; ?>
        <input type="hidden" name="<?php echo esc_attr( $field['name'] ); ?>" class="upload_image_id" value="<?php echo esc_attr( $field['value'] ); ?>" />
        <a href="#" class="button lk_upload_image_button tips"><?php echo esc_html__( 'Upload/Add image', 'landkit-extensions' ); ?></a>
        <a href="#" class="button lk_remove_image_button tips"><?php echo esc_html__( 'Remove this image', 'landkit-extensions' ); ?></a>
    </div>
    <?php
}